#!/usr/bin/env python

from distutils.core import setup

setup(name='Emojipedia',
      packages=['emojipedia'],
      version='0.3.2',
      description='Emoji data from Emojipedia',
      author='Benjamin Congdon',
      author_email='bcongdo2@illinois.edu',
      license='MIT',
      url='https://github.com/benjamincongdon',
      download_url='https://github.com/benjamincongdon/' +
                   'python-emojipedia/tarball/0.2',
      keywords=['emoji', 'emojipedia'],
      classifiers=['Programming Language :: Python :: 2',
                   'Programming Language :: Python :: 2.6',
                   'Programming Language :: Python :: 2.7',
                   'Programming Language :: Python :: 3',
                   'Programming Language :: Python :: 3.5',
                   'Programming Language :: Python :: 3.6',
                   'Topic :: Communications :: Chat',
                   'Topic :: Text Processing',
                   'Topic :: Utilities'],
      )
